@@ -4,6 +4,8 @@
 #ifndef _ContourPlane_h
 #define _ContourPlane_h
 
+#include <stdlib.h>		// use size_t
+
 #include "spoint.h"		// Use IRegion
 #include "contour.h"		// Use Contour_Levels
 
@@ -24,7 +26,7 @@ public:
 	const IRegion &		region() const { return mRegion; }
 	const Contour_Levels & 	positive_levels() const { return mPosLevels; }
 	const Contour_Levels & 	negative_levels() const { return mNegLevels; }
-	int			memory_use();
+	size_t			memory_use();
 
 private:
 	Spectrum	*mSpectrum;
