@@ -19,8 +19,9 @@
  *	LinefitVolume	- a volume that gets filled with the intensity
  *			  computed from the LinefitPeaks it is holding.
  */
-#include <math.h>		// Use sqrt(), exp()
+#include <math.h>		// Use sqrt(), exp(), fabs()
 #include <float.h>		// Use DBL_MAX
+#include <stdlib.h>		// use size_t
 #include <string.h>		// Use memset()
 
 #include "dataregion.h"		// Use Marked_Region
@@ -34,6 +35,7 @@
 #include "simplex.h"
 #include "spectrum.h"
 #include "spoint.h"		// Use SPoint
+#include "subarray.h"		// use Subarray_Iterator
 #include "utility.h"		// Use fatal_error()
 #include "wait.h"		// use Wait
 
@@ -248,7 +250,7 @@ bool LinefitPeak::update_peak(double residual, int npoints, Reporter &rr)
 
 	double	vol = fit_volume();
 	double fe = (vol != 0 ?
-		     npoints * sqrt(residual / npoints) / abs(vol) :
+		     npoints * sqrt(residual / npoints) / fabs(vol) :
 		     0);
 
 	SPoint	pos = sp->map(position(), INDEX, PPM);
@@ -336,8 +338,8 @@ const Integration_Parameters &LinefitPeak::integration_parameters() const
 static void compute_fit_heights(const List &peaks, const Marked_Region &r,
 				float *heights)
 {
-  int size = r.region().volume() * sizeof(float);
-  memset(heights, 0, size);
+  memset(heights, 0, r.region().volume() * sizeof(float));
+
   for (int k = 0 ; k < peaks.size() ; ++k)
     {
       LinefitPeak *lp = (LinefitPeak *) peaks[k];
@@ -602,7 +604,7 @@ static double square_difference(float *d, const Marked_Region &dr)
   for ( ; !p.finished() ; p.next())
     if (dr.is_marked(p.position()))
       {
-	int k = p.index();
+	offset_type k = p.index();
 	double diff = d[k] - d2[k];
 	sum += diff * diff;
       }
