@@ -252,7 +252,7 @@ private:
   bool big_endian;
   IPoint axis_step;
 
-  long block_location(const IPoint &block);
+  offset_type block_location(const IPoint &block);
 };
 
 static IPoint nih_data_size(const NIH_Header &hnih);
@@ -264,10 +264,10 @@ static List nih_axis_labels(const NIH_Header &hnih);
 static bool read_nih_header(FILE *nihfile, const Stringy &path,
 			    NIH_Header *h, Stringy *error_msg);
 static Stringy read_nih_label(int position, FILE *nihfile);
-static bool read_nih_float(int position, FILE *nihfile,
+static bool read_nih_float(offset_type position, FILE *nihfile,
 			   bool big_endian, float *value);
-static bool read_nih_floats(int position, int num, FILE *nihfile,
-			    bool big_endian, float *value);
+static bool read_nih_floats(offset_type position, offset_type num,
+			    FILE *nihfile, bool big_endian, float *value);
 
 // ----------------------------------------------------------------------------
 //
@@ -349,8 +349,8 @@ NIH_Block_File::~NIH_Block_File()
 //
 bool NIH_Block_File::read_block(const IPoint &block, float *values)
 {
-  long position = block_location(block);
-  long size = block_volume();
+  offset_type position = block_location(block);
+  offset_type size = block_volume();
 
   return read_nih_floats(position, size, this->fp, this->big_endian, values);
 }
@@ -364,9 +364,9 @@ bool NIH_Block_File::write_block(const IPoint &, float *)
 
 // ----------------------------------------------------------------------------
 //
-long NIH_Block_File::block_location(const IPoint &block)
+offset_type NIH_Block_File::block_location(const IPoint &block)
 {
-  long offset = FDATASIZE;
+  offset_type offset = FDATASIZE;
 
   for (int a = 0 ; a < block.dimension() ; ++a)
     offset += axis_step[a] * block[a];
@@ -527,16 +527,18 @@ static bool read_nih_header(FILE *nihfile, const Stringy &path,
   //
   // Check if file is too small.
   //
-  unsigned long dsize = 1;
+  offset_type dsize = 1;
   for (int d = 0 ; d < h->dim ; ++d)
     dsize *= h->size[d];
-  unsigned long expected_size = 4 * (FDATASIZE + dsize);
-  unsigned long size = file_size(path);
+  offset_type expected_size = 4 * (FDATASIZE + dsize);
+  offset_type size = file_size(path);
   if (size < expected_size)
     {
       *error_msg = formatted_string("%s is smaller (%ld bytes) "
 				    "than expected (%ld bytes)",
-				    path.cstring(), size, expected_size);
+				    path.cstring(),
+				    static_cast<long>(size),
+				    static_cast<long>(expected_size));
       return false;
     }
 
@@ -559,8 +561,8 @@ static Stringy read_nih_label(int position, FILE *nihfile)
 
 // ----------------------------------------------------------------------------
 //
-static bool read_nih_float(int position, FILE *nihfile, bool big_endian,
-			   float *value)
+static bool read_nih_float(offset_type position, FILE *nihfile,
+			   bool big_endian, float *value)
 {
   return (seek_position(nihfile, 4 * position, 0) &&
 	  read_f32(value, nihfile, big_endian));
@@ -568,8 +570,8 @@ static bool read_nih_float(int position, FILE *nihfile, bool big_endian,
 
 // ----------------------------------------------------------------------------
 //
-static bool read_nih_floats(int position, int num, FILE *nihfile,
-			    bool big_endian, float *value)
+static bool read_nih_floats(offset_type position, offset_type num,
+			    FILE *nihfile, bool big_endian, float *value)
 {
   return (seek_position(nihfile, 4 * position, 0) &&
 	  read_f32_array(value, num, nihfile, big_endian));
