@@ -28,7 +28,7 @@ ulimit -s 4096
 #
 if test "${1:0:4}" == "-psn"
 then
-	exec "$SPARKY/bin/sparky" ${*:2}
+	exec "$SPARKY/bin/sparky" "${@:2}"
 else
-	exec "$SPARKY/bin/sparky" ${*:1}
+	exec "$SPARKY/bin/sparky" "${@:1}"
 fi
