@@ -387,6 +387,8 @@ class noeshow_dialog(tkutil.Dialog):
     found = []
     for peak in peaks:
       rlist = peak.resonances()
+      if len(rlist) > 2:
+        rlist = filter(lambda r: r and r.atom.nucleus == '1H', rlist)
       if len(rlist) == 2:
         r1, r2 = rlist
         if r1 and r2:
@@ -595,7 +597,7 @@ def setup_chimera():
     chimera_site_packages = os.path.join(chimera_path, 'bin', 'Lib',
                                          'site-packages')
   else:
-    chimera_site_packages = os.path.join(chimera_path, 'lib', 'python2.3',
+    chimera_site_packages = os.path.join(chimera_path, 'lib', 'python2.4',
                                          'site-packages')
   
   sys.path.insert(0, chimera_site_packages)
